@@ -9,7 +9,7 @@ from trexlib.utils.security_util import generate_user_id, hash_password
 from trexmodel.models.datastore.ndb_models import BaseNModel, DictModel
 from trexlib.utils.string_util import random_string
 from trexlib.utils.common.common_util import logger
-from trexlib import conf
+from trexconf import conf
 
 
 class SuperUser(UserMin):
