@@ -13,7 +13,7 @@ from trexlib.utils.string_util import is_not_empty, is_empty
 import logging
 from trexlib.utils.common.date_util import convert_date_to_datetime,\
     to_day_of_year
-from trexmodel import conf, program_conf
+from trexconf import conf, program_conf
 from six import string_types
 from datetime import datetime, timedelta
 from trexmodel.models.datastore.membership_models import MerchantTierMembership,\
@@ -46,6 +46,7 @@ class Customer(BaseNModel, DictModel, FullTextSearchable):
     birth_day_in_year           = ndb.IntegerProperty(required=False)
     gender                      = ndb.StringProperty(required=False)
     reference_code              = ndb.StringProperty(required=True)
+    referral_code               = ndb.StringProperty(required=False)
     
     mobile_app_installed        = ndb.BooleanProperty(required=False, default=False)
     
@@ -68,6 +69,8 @@ class Customer(BaseNModel, DictModel, FullTextSearchable):
     entitled_membership_reward_summary          = ndb.JsonProperty()
     entitled_lucky_draw_ticket_summary          = ndb.JsonProperty(required=False)
     
+    referrer_code                               = ndb.StringProperty(required=False)
+    
     kpi_summary                                 = ndb.JsonProperty()
     
     device_details                              = ndb.JsonProperty()
@@ -78,8 +81,9 @@ class Customer(BaseNModel, DictModel, FullTextSearchable):
                            'tags_list', 'memberships_list', 'registered_merchant_acct', 'entitled_membership_reward_summary',
                            'reward_summary', 'entitled_voucher_summary', 'prepaid_summary', 'kpi_summary', 'entitled_lucky_draw_ticket_summary',
                            'entitled_birthday_reward_summary', 'tier_membership_key',
-                           'registered_outlet_key', 'registered_merchant_acct_key', 'registered_datetime', 'modified_datetime',
-                           'registered_user_acct',
+                           'registered_outlet_key', 'merchant_account_key', 
+                           'registered_datetime', 'modified_datetime',
+                           'registered_user_acct','referral_code',
                            
                            ]
     
@@ -113,6 +117,11 @@ class Customer(BaseNModel, DictModel, FullTextSearchable):
     def registered_merchant_acct_key(self):
         if self.merchant_acct:
             return self.merchant_acct.urlsafe().decode("utf-8")
+        
+    @property
+    def merchant_account_key(self):
+        if self.merchant_acct:
+            return self.merchant_acct.urlsafe().decode("utf-8")    
     
     @property
     def registered_outlet(self):
@@ -267,6 +276,7 @@ class Customer(BaseNModel, DictModel, FullTextSearchable):
         for ticket in tickets_list:
             ticket.patch_prize_image_base_url()
             Customer.update_ticket_into_lucky_draw_ticket_summary(customer_acct, ticket.to_configuration())
+    
     @classmethod
     def get_by_reference_code(cls, reference_code, merchant_acct):
         return cls.query(ndb.AND(cls.reference_code==reference_code, cls.merchant_acct==merchant_acct.create_ndb_key())).get()
@@ -353,6 +363,7 @@ class Customer(BaseNModel, DictModel, FullTextSearchable):
                                mobile_phone             = user_acct.mobile_phone, 
                                gender                   = user_acct.gender, 
                                reference_code           = user_acct.reference_code, 
+                               referral_code            = user_acct.referral_code,
                                birth_date               = user_acct.birth_date, 
                                birth_date_date_str      = user_acct.birth_date_date_str, 
                                birth_day_in_year        = user_acct.birth_day_in_year,
