@@ -5,17 +5,9 @@ Created on 19 Aug 2021
 '''
 
 from google.cloud import ndb
-from trexmodel.models.datastore.ndb_models import BaseNModel, DictModel, FullTextSearchable
-from trexmodel.models.datastore.user_models import User
-from trexmodel.models.datastore.merchant_models import MerchantAcct, Outlet, MerchantUser
-from trexlib.utils.string_util import is_empty, is_not_empty
-import logging, json
-from trexmodel import conf, program_conf
-from trexlib.utils.string_util import random_string
-from datetime import datetime, timedelta
-from trexmodel.models.datastore.customer_models import Customer
-import trexmodel.conf as model_conf
-from trexmodel.models.datastore.model_decorators import model_transactional
+from trexmodel.models.datastore.ndb_models import BaseNModel, DictModel
+from trexmodel.models.datastore.merchant_models import MerchantUser
+import logging
 
 logger = logging.getLogger('model')
 
