@@ -4,7 +4,7 @@ Created on 12 May 2023
 @author: jacklok
 '''
 import logging
-from trexmodel import program_conf
+from trexconf import program_conf
 import trexmodel.conf as model_conf
 from trexmodel.models.datastore.ndb_models import BaseNModel, DictModel
 from google.cloud import ndb
@@ -58,9 +58,9 @@ class LuckyDrawProgram(LuckyDrawBase):
                                            'created_datetime', 'modified_datetime','archived_datetime', 'completed_status',
                                            'condition_settings', 'exclusivity_settings', 'prize_settings',
                                            'exclusive_tags_list', 'exclusive_memberships_list', 'exclusive_tier_memberships_list',  
-                                           'created_by_username', 'modified_by_username', 'completed_prograss_in_percentage',
+                                           'created_by_username', 'modified_by_username', 'completed_progress_in_percentage',
                                            'is_published', 'is_enabled','is_disabled', 'totalPrizePossibility',
-                                           'image_storage_filename', 'image_public_url', 'test_result', 
+                                           'image_storage_filename', 'image_public_url', 'test_result', 'is_expired',
                                            ]
     
     
@@ -95,6 +95,10 @@ class LuckyDrawProgram(LuckyDrawBase):
     def is_disabled(self):
         return self.enabled==False
     
+    @property
+    def is_expired(self):
+        return self.end_date<datetime.now().date()
+    
     @property
     def is_archived(self):
         return self.archived
@@ -119,7 +123,7 @@ class LuckyDrawProgram(LuckyDrawBase):
             return ','.join(self.exclusivity_settings.get('tier_memberships')) or ''
     
     @property
-    def completed_prograss_in_percentage(self):
+    def completed_progress_in_percentage(self):
         return program_conf.lucky_draw_program_completed_progress_percentage(self.completed_status)
     
     @property
