@@ -9,13 +9,12 @@ from trexmodel.models.datastore.ndb_models import BaseNModel, DictModel
 import trexmodel.conf as model_conf
 from trexlib.utils.string_util import is_not_empty, random_string
 from trexmodel.models.datastore.merchant_models import MerchantAcct, \
-    MerchantUser, Outlet
+    MerchantUser
 import logging
 from dateutil.relativedelta import relativedelta
-from datetime import timedelta
 
 from datetime import datetime
-from trexmodel import program_conf
+from trexconf import program_conf
 
 logger = logging.getLogger('model')
 
