@@ -14,10 +14,9 @@ from trexlib.utils.string_util import random_number, is_empty, is_not_empty,\
     split_by_length, random_string
 import logging
 from datetime import datetime, timedelta
-from trexmodel import conf, program_conf
+from trexconf import conf, program_conf
 from trexmodel.models.datastore.system_models import Tagging
 from trexmodel.models.datastore.model_decorators import model_transactional
-from trexlib.utils.common.common_util import sort_dict_list
 from trexmodel.program_conf import LOYALTY_PACKAGE_LITE, LOYALTY_PRODUCT
 
 logger = logging.getLogger('model')
@@ -67,30 +66,32 @@ class MerchantAcct(MerchantMin):
     outlet_count                            = ndb.IntegerProperty(default=0)
     
     published_program_configuration                 = ndb.JsonProperty()
+    published_referral_program_configuration        = ndb.JsonProperty()
     published_voucher_configuration                 = ndb.JsonProperty()
     published_redemption_catalogue_configuration    = ndb.JsonProperty()
     
     membership_configuration                        = ndb.JsonProperty()
     tier_membership_configuration                   = ndb.JsonProperty()
     
-    reward_naming_configuration             = ndb.JsonProperty()
+    reward_naming_configuration                     = ndb.JsonProperty()
     
-    prepaid_configuration                   = ndb.JsonProperty()
+    prepaid_configuration                           = ndb.JsonProperty()
     
-    lucky_draw_configuration                = ndb.JsonProperty(required=False)
+    lucky_draw_configuration                        = ndb.JsonProperty(required=False)
     
-    product_modifier_configuration          = ndb.JsonProperty()
+    product_modifier_configuration                  = ndb.JsonProperty()
     
-    program_settings                        = ndb.JsonProperty()
+    program_settings                                = ndb.JsonProperty()
     
-    stat_figure_update_interval_in_minutes  = conf.MERCHANT_STAT_FIGURE_UPDATE_INTERVAL_IN_MINUTES
-    stat_figure_update_datetime_format      = '%d-%m-%Y %H:%M:%S'
+    stat_figure_update_interval_in_minutes          = conf.MERCHANT_STAT_FIGURE_UPDATE_INTERVAL_IN_MINUTES
+    stat_figure_update_datetime_format              = '%d-%m-%Y %H:%M:%S'
     
     dict_properties = ['company_name', 'brand_name', 'contact_name', 'business_reg_no', 'mobile_phone', 
                        'office_phone', 'fax_phone', 'email', 'account_code', 'country',
                        'registered_datetime', 'modified_datetime', 'plan_start_date', 'plan_end_date', 'currency_code', 
-                       'timezone',
-                       'published_program_configuration', 'published_voucher_configuration', 'membership_configuration', 
+                       'timezone', 'effective_referral_program_count',
+                       'published_program_configuration', 'published_referral_program_configuration', 
+                       'published_voucher_configuration', 'membership_configuration', 
                        'tier_membership_configuration', 'prepaid_configuration', 'lucky_draw_configuration', 'product_modifier_configuration',
                        'dashboard_stat_figure', 'program_settings', 'is_tier_membership_configured', 'website', 
                        'product_package', 'loyalty_package','account_plan','outlet_count', 'outlet_limit',
@@ -123,6 +124,31 @@ class MerchantAcct(MerchantMin):
         
         return LOYALTY_PACKAGE_LITE
     
+    @property
+    def effective_referral_program_count(self):
+        if self.published_referral_program_configuration:
+            program_count = self.published_referral_program_configuration.get('count',0)
+            if program_count>0:
+                check_effective_count = 0
+                program_list = self.published_referral_program_configuration.get('programs');
+                today_date = datetime.today()
+                for program_details in program_list:
+                    start_date_str = program_details.get('start_date')
+                    start_date = datetime.strptime(start_date_str, '%d-%m-%Y')
+                    
+                    end_date_str = program_details.get('end_date')
+                    end_date = datetime.strptime(end_date_str, '%d-%m-%Y')
+                    
+                    if start_date<=today_date and today_date<=end_date:
+                        check_effective_count+=1
+                
+                return check_effective_count
+                    
+            else:
+                return program_count
+                
+        return 0
+    
     @property
     def outlet_limit(self):
         if self.account_plan:
@@ -213,6 +239,47 @@ class MerchantAcct(MerchantMin):
         if self.lucky_draw_configuration.get('settings'):
             return self.lucky_draw_configuration['settings']['ticket_image_url']
     
+    @property
+    def referrer_promote_title(self):
+        if is_not_empty(self.program_settings):
+            if self.program_settings.get('referral_program'):
+                return self.program_settings.get('referral_program').get('referrer_promote_title', '')
+        return ''
+        
+    @property
+    def referee_promote_title(self):
+        if is_not_empty(self.program_settings):
+            if self.program_settings.get('referral_program'):
+                return self.program_settings.get('referral_program').get('referee_promote_title', '')      
+        return ''
+        
+    @property
+    def referrer_promote_desc(self):
+        if is_not_empty(self.program_settings):
+            if self.program_settings.get('referral_program'):
+                return self.program_settings.get('referral_program').get('referrer_promote_desc', '')
+        return ''
+            
+    @property
+    def referee_promote_desc(self):
+        if is_not_empty(self.program_settings):
+            if self.program_settings.get('referral_program'):
+                return self.program_settings.get('referral_program').get('referee_promote_desc', '')            
+        return ''
+        
+    @property
+    def referrer_promote_image(self):
+        if is_not_empty(self.program_settings):
+            if self.program_settings.get('referral_program'):
+                return self.program_settings.get('referral_program').get('referrer_promote_image')
+            
+    @property
+    def referee_promote_image(self):
+        if is_not_empty(self.program_settings):
+            if self.program_settings.get('referral_program'):
+                return self.program_settings.get('referral_program').get('referee_promote_image')        
+        
+    
     @staticmethod
     def default_program_settings():
         return {
@@ -222,7 +289,104 @@ class MerchantAcct(MerchantMin):
                 'membership_renew_late_day'             : 30,
                 
                 }
+    
+    def update_referrer_program_promote_text(self, 
+                                             promote_title=None, 
+                                             promote_desc=None,
+                                             modified_by=None):
+        modified_by_username = None
         
+        if is_not_empty(modified_by):
+            if isinstance(modified_by, MerchantUser):
+                modified_by_username = modified_by.username
+        
+        if is_empty(self.program_settings):
+            self.program_settings = {
+                                    'referral_program':{}
+                                    }
+        else:
+            if is_empty(self.program_settings.get('referral_program')):
+                self.program_settings['referral_program'] = {}
+        
+        self.modified_by            = modified_by.create_ndb_key()
+        self.modified_by_username   = modified_by_username
+            
+        self.program_settings['referral_program']['referrer_promote_title'] =  promote_title
+        self.program_settings['referral_program']['referrer_promote_desc']  =  promote_desc
+        self.put() 
+        
+    def update_referee_program_promote_text(self, 
+                                             promote_title=None, 
+                                             promote_desc=None, 
+                                             modified_by=None):
+        modified_by_username = None
+        
+        if is_not_empty(modified_by):
+            if isinstance(modified_by, MerchantUser):
+                modified_by_username = modified_by.username
+        
+        if is_empty(self.program_settings):
+            self.program_settings = {
+                                    'referral_program':{}
+                                    }
+        else:
+            if is_empty(self.program_settings.get('referral_program')):
+                self.program_settings['referral_program'] = {}
+        
+        self.modified_by            = modified_by.create_ndb_key()
+        self.modified_by_username   = modified_by_username
+            
+        self.program_settings['referral_program']['referee_promote_title'] =  promote_title
+        self.program_settings['referral_program']['referee_promote_desc']  =  promote_desc
+        self.put()       
+        
+    def upload_referrer_program_promote_image(self, image_public_url=None, image_storage_filename=None, modified_by=None):
+        
+        modified_by_username = None
+        
+        if is_not_empty(modified_by):
+            if isinstance(modified_by, MerchantUser):
+                modified_by_username = modified_by.username
+        
+        if is_empty(self.program_settings):
+            self.program_settings = {
+                                    'referral_program':{}
+                                    }
+        else:
+            if is_empty(self.program_settings.get('referral_program')):
+                self.program_settings['referral_program'] = {}
+        
+        self.program_settings['referral_program']['referrer_promote_image']             = image_public_url
+        self.program_settings['referral_program']['referrer_promote_image_filename']    = image_storage_filename
+        
+        self.modified_by            = modified_by.create_ndb_key()
+        self.modified_by_username   = modified_by_username
+        
+        self.put()
+        
+    def upload_referee_program_promote_image(self, image_public_url=None, image_storage_filename=None, modified_by=None):
+        
+        modified_by_username = None
+        
+        if is_not_empty(modified_by):
+            if isinstance(modified_by, MerchantUser):
+                modified_by_username = modified_by.username
+        
+        if is_empty(self.program_settings):
+            self.program_settings = {
+                                    'referral_program':{}
+                                    }
+        else:
+            if is_empty(self.program_settings.get('referral_program')):
+                self.program_settings['referral_program'] = {}
+        
+        self.program_settings['referral_program']['referee_promote_image']          = image_public_url
+        self.program_settings['referral_program']['referee_promote_image_filename'] = image_storage_filename
+        
+        self.modified_by            = modified_by.create_ndb_key()
+        self.modified_by_username   = modified_by_username
+        
+        self.put()        
     
     @staticmethod
     def update_details(merchant_acct, company_name=None, brand_name=None, business_reg_no=None, contact_name=None, 
@@ -408,6 +572,32 @@ class MerchantAcct(MerchantMin):
             
         self.put()
         
+    def update_published_referral_program(self, program_configuration):
+        if is_empty(self.published_referral_program_configuration):
+            self.published_referral_program_configuration = {
+                                                'programs'  :[program_configuration],
+                                                'count'     : 1,
+                                                } 
+                                            
+        else:
+            self.flush_dirty_program_configuration()
+            existing_programs_list  = self.published_referral_program_configuration.get('programs')
+            
+            program_key = program_configuration.get('program_key')
+            index = 0
+            for p in existing_programs_list:
+                if p.get('program_key') == program_key:
+                    existing_programs_list.pop(index)
+                
+                index = index+1
+            
+            existing_programs_list.append(program_configuration)
+            
+            self.published_referral_program_configuration['programs']    = existing_programs_list
+            self.published_referral_program_configuration['count']       = len(existing_programs_list) 
+            
+        self.put()    
+        
     def add_voucher(self, voucher_configuration):
         if is_empty(self.published_voucher_configuration):
             self.published_voucher_configuration = {
@@ -678,6 +868,42 @@ class MerchantAcct(MerchantMin):
             
         self.put() 
         
+    def remove_program_from_published_referral_program_configuration(self, program_key_to_remove):
+        
+        logger.debug('remove_program_from_published_referral_program_configuration: program_key_to_remove=%s', program_key_to_remove)
+        
+        #self.flush_dirty_program_configuration()
+        existing_programs_list  = self.published_referral_program_configuration['programs']
+        program_count           = len(existing_programs_list)
+        
+        logger.debug('program_count before remove=%s', program_count)
+        
+        index = 0
+        
+        for program in existing_programs_list:
+            
+            logger.debug('program_key=%s', program.get('program_key'))
+            
+            is_same_program_key = program.get('program_key') == program_key_to_remove
+            
+            logger.debug('is_same_program_key=%s', is_same_program_key)
+            
+            if is_same_program_key:
+                existing_programs_list.pop(index)
+                
+                logger.debug('Found program to be remove')
+                
+            index = index+1
+        
+        program_count = len(existing_programs_list)
+        
+        logger.debug('program_count after remove=%s', program_count)
+        
+        self.published_referral_program_configuration['programs']    = existing_programs_list
+        self.published_referral_program_configuration['count']       = program_count
+            
+        self.put()     
+        
     
         
     def remove_redeption_catalogue(self, catalogue_key):
@@ -993,14 +1219,15 @@ class MerchantAcct(MerchantMin):
         
         for program in published_program_configuration.get('programs'):
             if program.get('giveaway_method') == program_conf.PROGRAM_REWARD_GIVEAWAY_METHOD_SYSTEM:
-                logger.debug('giveaway system condition=%s', program.get('program_settings').get('giveaway_system_settings').get('giveaway_system_condition'))
-                if program.get('program_settings').get('giveaway_system_settings').get('giveaway_system_condition') == program_conf.GIVEAWAY_SYSTEM_CONDITION_DATA_IMPORT:
-                    logger.debug('giveaway reward_format=%s', program.get('reward_format'))
-                    if program.get('reward_format') == target_reward_format:
-                        data_import_giveaway_programs.append({
-                                                            'program_key'   : program.get('program_key'),
-                                                            'label'         : program.get('label'),
-                                                            })
+                if program.get('program_settings').get('giveaway_system_settings') and program.get('program_settings').get('giveaway_system_settings').get('giveaway_system_condition'):
+                    logger.debug('giveaway system condition=%s', program.get('program_settings').get('giveaway_system_settings').get('giveaway_system_condition'))
+                    if program.get('program_settings').get('giveaway_system_settings').get('giveaway_system_condition') == program_conf.GIVEAWAY_SYSTEM_CONDITION_DATA_IMPORT:
+                        logger.debug('giveaway reward_format=%s', program.get('reward_format'))
+                        if program.get('reward_format') == target_reward_format:
+                            data_import_giveaway_programs.append({
+                                                                'program_key'   : program.get('program_key'),
+                                                                'label'         : program.get('label'),
+                                                                })
                     
         return data_import_giveaway_programs
     
@@ -1666,4 +1893,76 @@ class BannerFile(BaseNModel, DictModel):
         old_logo_blob = bucket.get_blob(banner_file.banner_file_storage_filename) 
         if old_logo_blob:
             old_logo_blob.delete()
-            banner_file.delete()    
+            banner_file.delete()   
+            
+class MerchantNewsFile(BaseNModel, DictModel):
+    '''
+    Merchant Account as ancestor
+    '''
+    label                         = ndb.StringProperty(required=False)
+    desc                          = ndb.StringProperty(required=False)
+    news_text                     = ndb.StringProperty(required=False)
+    
+    news_file_type                = ndb.StringProperty(required=True)
+    news_file_public_url          = ndb.StringProperty(required=True)
+    news_file_storage_filename    = ndb.StringProperty(required=True)
+    start_date                    = ndb.DateProperty(required=True)
+    end_date                      = ndb.DateProperty(required=True)
+    
+    
+    dict_properties = ['news_file_public_url', 'news_file_storage_filename', 'news_file_type', 'label', 'desc', 'news_text', 'start_date', 'end_date']
+    
+    @staticmethod
+    def list_by_merchant_acct(merchant_acct):
+        result = MerchantNewsFile.query(ancestor=merchant_acct.create_ndb_key()).fetch(limit=conf.MAX_FETCH_RECORD)
+        return result
+    
+    @staticmethod
+    def create(merchant_acct, label=None, desc=None, news_text=None):
+        news_file = MerchantNewsFile(
+                            parent      = merchant_acct.create_ndb_key(),
+                            label       = label,
+                            desc        = desc,
+                            news_text   = news_text,
+                            )
+        
+        news_file.put()
+    
+    @staticmethod
+    def upload_file(merchant_news, uploading_file, merchant_acct, bucket, news_file_type=None):
+        file_prefix                         = random_string(8)
+        news_file_storage_filename          = 'merchant/'+merchant_acct.key_in_str+'/news/'+file_prefix+'-'+uploading_file.filename
+        blob                                = bucket.blob(news_file_storage_filename)
+        
+        logger.debug('news_file_storage_filename=%s', news_file_storage_filename)
+        
+        blob.upload_from_string(
+                uploading_file.read(),
+                content_type=uploading_file.content_type
+            )
+        
+        uploaded_url        = blob.public_url
+        
+        logger.debug('uploaded_url=%s', uploaded_url)
+        logger.debug('news_file_type=%s', news_file_type)
+        
+        if is_not_empty(merchant_news.news_file_storage_filename):
+            old_logo_blob = bucket.get_blob(merchant_news.news_file_storage_filename)
+            if old_logo_blob:
+                old_logo_blob.delete()
+            
+        
+        merchant_news.news_file_public_url          = uploaded_url
+        merchant_news.news_file_storage_filename    = news_file_storage_filename
+        merchant_news.news_file_type                = news_file_type
+        
+        
+        merchant_news.put()
+    
+    @staticmethod
+    def remove_file(news_file, bucket):
+        
+        old_logo_blob = bucket.get_blob(news_file.news_file_storage_filename) 
+        if old_logo_blob:
+            old_logo_blob.delete()
+            news_file.delete()                
