@@ -7,7 +7,7 @@ from trexmodel.program_conf import REWARD_FORMAT_MAP, REWARD_FORMAT_PREPAID
 from trexmodel.models.datastore.message_models import Message
 from trexmodel.conf import MESSAGE_CATEGORY_REWARD, MESSAGE_STATUS_NEW,\
     MESSAGE_CATEGORY_REDEEM
-from trexmodel import program_conf
+from trexconf import program_conf
 from babel.numbers import format_currency
 import logging
 
