@@ -8,6 +8,7 @@ from google.cloud import ndb
 import logging
 
 import time
+from trexlib.utils.log_util import get_tracelog
 logger = logging.getLogger('model')
 
 def model_transactional(
@@ -19,7 +20,7 @@ def model_transactional(
         desc=None):
     
     if desc is None:
-        desc=''
+        desc='modeal transaction'
     
     
     def transactional_wrapper(wrapped):
@@ -28,16 +29,28 @@ def model_transactional(
             @ndb.transactional(retries=retries, read_only=read_only, join=join, xg=xg, propagation=propagation)
             def callback():
                 start = time.time()
+                #result = None
                 try:
+                    
+                    logger.debug('wrapped=%s', wrapped)
                     result =  wrapped(*args, **kwargs)
+                    
+                    logger.debug('result=%s', result)
+                    
+                    end = time.time()
+                    total_nanoseconds = int((end-start) * 1000000)
+                    logger.debug('-------------------{}--------------------------'.format(desc))
+                    logger.debug('transaction took %s nanoseconds', total_nanoseconds)
+                    logger.debug('----------------------------------------------------------')
+                    
+                    return result
+                    
+                
                 except:
-                    pass
-                end = time.time()
-                total_nanoseconds = int((end-start) * 1000000)
-                logger.debug('-------------------{}--------------------------'.format(desc))
-                logger.debug('transaction took %s nanoseconds', total_nanoseconds)
-                logger.debug('----------------------------------------------------------')
-                return result
+                    logger.error('Failed due to %s', get_tracelog())
+                    raise
+                
+                
             
             return callback()
 
