@@ -12,9 +12,9 @@ from six import string_types
 from trexlib.utils.common.date_util import increase_date 
 import logging
 #from google.cloud.ndb._datastore_query import Cursor
-from google.cloud.ndb import Cursor
-from trexlib import conf as lib_conf 
-from trexmodel import conf as model_conf
+#from google.cloud.ndb import Cursor
+from trexconf import conf as lib_conf 
+from trexconf import conf as model_conf
 from google.cloud.datastore.helpers import GeoPoint
  
 logger = logging.getLogger('model') 
@@ -288,7 +288,7 @@ class BaseNModel(DictModel, NDBModel):
     def count_with_condition_query(cls, query, limit=model_conf.MAX_FETCH_RECORD):    
         
         
-        return query.count(limit=limit, keys_only=True)
+        return query.count(limit=limit)
     
     @classmethod
     def list_all(cls, offset=0,  start_cursor=None, return_with_cursor=False, keys_only=False, 
@@ -411,7 +411,7 @@ class FullTextSearchable(ndb.Model):
             
         logger.debug('query=%s', query)
         
-        return query.count(limit=limit, keys_only=True)
+        return query.count(limit=limit)
             
            
         
