@@ -3,8 +3,8 @@ from google.cloud import ndb
 from trexmodel.models.datastore.ndb_models import BaseNModel, DictModel
 from trexmodel.models.datastore.merchant_models import Outlet
 from trexlib.utils.string_util import random_number, is_not_empty
-import logging, json
-from trexmodel import conf
+import logging
+from trexconf import conf
 from datetime import datetime
 from trexmodel.models.datastore.product_models import ProductCatalogue
 from trexmodel.models.datastore.model_decorators import model_transactional
