@@ -9,11 +9,9 @@ from trexmodel.models.datastore.user_models import User
 from trexmodel.models.datastore.merchant_models import MerchantAcct, Outlet, MerchantUser
 import logging, json
 from trexmodel import conf, program_conf
-from trexlib.utils.string_util import random_string, random_number, is_not_empty
-from datetime import datetime, timedelta
-import trexmodel.conf as model_conf
+from trexlib.utils.string_util import random_number, is_not_empty
+from datetime import datetime
 from trexlib.utils.common.common_util import sort_dict_list
-from trexmodel.utils.model.model_util import generate_transaction_id
 from dateutil.relativedelta import relativedelta
 from trexmodel.program_conf import PRODUCT_TYPES, LOYALTY_PRODUCT
 from trexlib.utils.crypto_util import encrypt
@@ -568,9 +566,11 @@ class CustomerPrepaidReward(BaseNModel,DictModel):
         topup_prepaid_rate  = CustomerPrepaidReward.__calculate_topup_prepaid_rate(prepaid_scheme_details)
         
         topup_by_key = None
+        topup_by_username = None
         
         if topup_by:
             topup_by_key = topup_by.create_ndb_key()
+            topup_by_username = topup_by.username
             
         if topup_datetime is None:
             topup_datetime = datetime.utcnow()
@@ -591,7 +591,7 @@ class CustomerPrepaidReward(BaseNModel,DictModel):
                                                             invoice_id              = invoice_id,
                                                             
                                                             topup_by                = topup_by_key,
-                                                            
+                                                            topup_by_username       = topup_by_username, 
                                                             topup_datetime          = topup_datetime,    
                                                             )
         
@@ -599,6 +599,42 @@ class CustomerPrepaidReward(BaseNModel,DictModel):
         
         return prepaid_topup_reward
     
+    @staticmethod
+    def create(customer_acct, topup_outlet, 
+               topup_amount=0, topup_unit=0, topup_prepaid_rate = 1, 
+               prepaid_amount=.0, prepaid_scheme_details={}, 
+               topup_datetime=None, topup_by=None,
+               transaction_id=None, invoice_id=None,
+               ):
+        
+        merchant_acct  = customer_acct.registered_merchant_acct
+        
+        topup_by_key = None
+        topup_by_username = None
+        
+        if topup_by:
+            topup_by_key = topup_by.create_ndb_key()
+            topup_by_username = topup_by.username
+            
+        CustomerPrepaidReward(
+            parent                  = customer_acct.create_ndb_key(),
+            merchant_acct           = merchant_acct.create_ndb_key(),
+            topup_outlet            = topup_outlet.create_ndb_key() if topup_outlet else None,
+            topup_amount            = topup_amount,
+            topup_unit              = topup_unit,
+            prepaid_amount          = prepaid_amount,
+            topup_prepaid_rate      = topup_prepaid_rate,
+            used_prepaid_amount     = .0,
+            prepaid_scheme_details  = prepaid_scheme_details,
+            
+            transaction_id          = transaction_id,
+            invoice_id              = invoice_id,
+            
+            topup_by                = topup_by_key,
+            topup_by_username       = topup_by_username, 
+            topup_datetime          = topup_datetime,   
+             
+            )
     
     @staticmethod
     def delete_all_by_customer(customer):
