@@ -5,14 +5,11 @@ Created on 23 Jul 2021
 '''
 from google.cloud import ndb
 from trexmodel.models.datastore.ndb_models import BaseNModel, DictModel, FullTextSearchable
-from trexmodel.models.datastore.user_models import User
 from trexmodel.models.datastore.merchant_models import MerchantAcct, MerchantUser
 from trexlib.utils.string_util import is_empty, is_not_empty
-import logging, json
-from trexmodel import conf, program_conf
+import logging
+from trexconf import conf
 from trexlib.utils.string_util import random_string
-from datetime import datetime, timedelta
-from trexmodel.models.datastore.customer_models import Customer
 import trexmodel.conf as model_conf
 from trexmodel.models.datastore.model_decorators import model_transactional
 from flask_babel import gettext
