@@ -7,11 +7,9 @@ from google.cloud import ndb
 from trexmodel.models.datastore.ndb_models import BaseNModel, DictModel
 import trexmodel.conf as model_conf
 from trexlib.utils.string_util import is_not_empty, random_string
-from trexmodel.models.datastore.merchant_models import MerchantAcct, Outlet,\
-    MerchantUser
-from trexmodel.models.datastore.coporate_models import CorporateAcct
+from trexmodel.models.datastore.merchant_models import MerchantAcct,MerchantUser
 import logging
-from trexmodel import conf, program_conf
+from trexconf import conf, program_conf
 from datetime import datetime
 from trexmodel.models.datastore.model_decorators import model_transactional
 from trexlib.utils.common.common_util import sort_list, sort_dict_list
@@ -252,10 +250,11 @@ class BaseProgram(BaseNModel, DictModel):
         
         program.put()  
         
-        merchant_acct = program.merchant_acct
-        merchant_acct.remove_program_from_published_program_configuration(program.key_in_str)
-        
-        cls.__remove_schedule_program(program)
+        if program.is_published:
+            merchant_acct = program.merchant_acct
+            merchant_acct.remove_program_from_published_program_configuration(program.key_in_str)
+            
+            cls.__remove_schedule_program(program)
         
     def to_configuration(self):
         program_configuration = {
@@ -279,7 +278,7 @@ class BaseProgram(BaseNModel, DictModel):
 class BasicRewardProgram(BaseProgram):
     
     @property
-    def completed_prograss_in_percentage(self):
+    def completed_progress_in_percentage(self):
         
         return program_conf.program_completed_progress_percentage(self.completed_status, self.loyalty_package)
     
@@ -560,7 +559,7 @@ class BasicRewardProgram(BaseProgram):
 class MerchantProgram(BasicRewardProgram):
     dict_properties                     = ['reward_base', 'giveaway_method', 'reward_format', 'completed_status', 'start_date', 'end_date', 'label','desc', 'program_settings', 
                                            'created_datetime', 'modified_datetime',  'enabled','completed_status','is_enabled', 'is_disabled', 'is_review_state', 
-                                           'is_published', 'archived', 'is_reward_amount_required', 'completed_prograss_in_percentage', 'completed_status_index',
+                                           'is_published', 'archived', 'is_reward_amount_required', 'completed_progress_in_percentage', 'completed_status_index',
                                            'exclusive_tags_list', 'exclusive_memberships_list', 'exclusive_tier_memberships_list',
                                            'is_recurring_scheme', 
                                            'expiration_type', 'expiration_date', 'expiration_value', 'is_expiration_date_type',
@@ -661,13 +660,13 @@ class MerchantTierRewardProgram(MerchantProgram):
     
     dict_properties                     = ['completed_status', 'start_date', 'end_date', 'label', 'desc', 'program_settings', 'reward_format',
                                            'created_datetime', 'modified_datetime',  'enabled','completed_status','is_enabled', 'is_disabled', 'is_review_state', 
-                                           'is_published', 'archived', 'completed_prograss_in_percentage', 'completed_status_index',
+                                           'is_published', 'archived', 'completed_progress_in_percentage', 'completed_status_index',
                                            'exclusive_tags_list', 'exclusive_memberships_list', 'exclusive_tier_memberships_list',
                                            'is_tier_recycle', 'is_show_progress', 'max_unlock_tier_count_per_trax',
                                            'created_by_username', 'modified_by_username', 'loyalty_package']
     
     @property
-    def completed_prograss_in_percentage(self):
+    def completed_progress_in_percentage(self):
         return program_conf.tier_reward_program_completed_progress_percentage(self.completed_status)
     
     @property
