@@ -7,7 +7,7 @@ from trexmodel.models.datastore.ndb_models import BaseNModel, DictModel
 from google.cloud import ndb
 from trexmodel.models.datastore.merchant_models import MerchantAcct, Outlet
 from trexmodel.models.datastore.user_models import User
-from trexmodel import conf
+from trexconf import conf
 from datetime import datetime, timedelta
 import logging
 
