@@ -10,12 +10,11 @@ from trexmodel.models.datastore.user_models import User
 from trexmodel.models.datastore.merchant_models import MerchantAcct, Outlet, MerchantUser
 from trexlib.utils.string_util import is_empty, is_not_empty
 import logging, json
-from trexmodel import conf, program_conf
+from trexconf import conf, program_conf
 from datetime import datetime, timedelta
 from trexmodel.utils.model.model_util import generate_transaction_id
 from trexmodel.models.datastore.reward_models import CustomerPointReward,\
     CustomerStampReward, CustomerEntitledVoucher
-from trexmodel.models.datastore.model_decorators import model_transactional
 from trexmodel.models.datastore.customer_models import Customer
 from trexmodel.models.datastore.transaction_models import CustomerTransaction
 from trexmodel.models.datastore.prepaid_models import CustomerPrepaidReward
