@@ -12,7 +12,7 @@ from trexmodel.models.datastore.program_models import MerchantProgram,\
 from trexmodel.models.datastore.voucher_models import MerchantVoucher
 from trexlib.utils.string_util import is_empty, is_not_empty
 import logging
-from trexmodel import conf, program_conf
+from trexconf import conf, program_conf
 from trexlib.utils.string_util import random_string
 from datetime import datetime, timedelta
 from trexmodel.utils.model.model_util import generate_transaction_id,\
@@ -479,8 +479,10 @@ class CustomerEntitledVoucher(CustomerEntitledReward):
     def to_redeem_info(self):
         return {
                 'redeem_code'       : self.redeem_code,
+                'entitled_datetime' : self.rewarded_datetime.strftime('%d-%m-%Y %H:%M'),
                 'effective_date'    : self.effective_date.strftime('%d-%m-%Y'),
                 'expiry_date'       : self.expiry_date.strftime('%d-%m-%Y'),
+                
                 }
     
     @staticmethod
