@@ -4,8 +4,7 @@ Created on 13 Apr 2020
 @author: jacklok
 '''
 from google.cloud import ndb
-import logging
-from trexmodel import conf as model_conf
+from trexconf import conf as model_conf
 from trexmodel.models.datastore.ndb_models import BaseNModel
 
  
