@@ -13,7 +13,7 @@ from trexlib.utils.string_util import is_not_empty
 from trexmodel.models.datastore.merchant_models import MerchantAcct, Outlet,\
     MerchantUser
 import logging
-from trexmodel import conf, program_conf
+from trexconf import conf, program_conf 
 from datetime import datetime, timedelta
 from trexmodel.utils.model.model_util import generate_transaction_id
 from trexmodel.models.datastore.membership_models import MerchantMembership,\
@@ -327,7 +327,14 @@ class CustomerTransaction(SalesTransaction):
                                    transact_datetime=transact_datetime, reward_giveaway_method=program_conf.PROGRAM_REWARD_GIVEAWAY_METHOD_MANUAL,
                                    is_sales_transaction = is_sales_transaction, allow_to_revert=allow_to_revert, 
                                    is_membership_purchase=is_membership_purchase, is_membership_renew=is_membership_renew,
-                                   )    
+                                   )
+        
+    @staticmethod
+    def create_referral_transaction(customer, transact_outlet=None, transact_datetime=None, ): 
+        return CustomerTransaction.create_system_transaction(customer, transact_outlet=transact_outlet, 
+                                   transact_datetime=transact_datetime, reward_giveaway_method=program_conf.PROGRAM_REWARD_GIVEAWAY_METHOD_REFERRAL,
+                                   allow_to_revert=False,
+                                   )        
     
     @staticmethod
     def create_from_sales_transaction(customer, sales_transaction):
