@@ -5,19 +5,16 @@ Created on 10 Apr 2020
 '''
 from google.cloud import ndb
 from trexmodel.models.datastore.ndb_models import BaseNModel, DictModel
-from trexlib.utils.string_util import random_number, is_not_empty, random_string,\
+from trexlib.utils.string_util import random_number, random_string,\
     is_empty
 from flask_login import UserMixin
 import logging  
 from trexlib.utils.security_util import generate_user_id, hash_password
 
-from trexlib import conf as lib_conf
-from trexmodel import conf as model_conf, conf
-import json
-from json import JSONEncoder
+from trexconf import conf as lib_conf
+from trexconf import conf as model_conf, conf
 from trexlib.utils.common.date_util import to_day_of_year
 from datetime import datetime, timedelta
-from flask_babel import gettext
 from trexmodel.conf import USER_STATUS_ANONYMOUS, ACCOUNT_LOCKED_IN_MINUTES
 
 logger = logging.getLogger("model")
@@ -127,6 +124,7 @@ class UserBase(UserMin):
     # User System Generated fields
     #---------------------------------------------------------------------------
     reference_code              = ndb.StringProperty(required=True)
+    referral_code               = ndb.StringProperty(required=True)
     
     #---------------------------------------------------------------------------
     # User Mutual Mandatory fields
@@ -202,16 +200,33 @@ class UserBase(UserMin):
     
     @classmethod
     def list_by_email(cls, email):
-        return User.query(ndb.AND(User.email==email)).fetch(limit=conf.MAX_FETCH_RECORD)
-        
+        return cls.query(ndb.AND(User.email==email)).fetch(limit=conf.MAX_FETCH_RECORD)
+    
     @classmethod
     def get_by_mobile_phone(cls, mobile_phone):
         return User.query(ndb.AND(User.mobile_phone==mobile_phone, User.deleted==False)).get()
     
+    @classmethod
+    def get_by_referral_code(cls, referral_code):
+        return User.query(ndb.AND(User.referral_code==referral_code)).get()
+    
     @classmethod
     def get_by_reset_password_token(cls, request_reset_password_token):
         return User.query(ndb.AND(User.request_reset_password_token==request_reset_password_token)).get()
     
+    @classmethod
+    def count_all(cls):
+        return cls.count(limit=conf.MAX_FETCH_RECORD)
+    
+    @classmethod
+    def _generate_referral_code(cls):
+        referral_code = random_string(8, is_human_mistake_safe=True)
+        checking_user = cls.get_by_referral_code(referral_code)
+        while checking_user is not None:
+            referral_code = random_string(8, is_human_mistake_safe=True)
+            checking_user = cls.get_by_referral_code(referral_code)
+        return referral_code
+    
     @classmethod
     def create(cls, name=None, email=None, mobile_phone=None, 
                gender=None, birth_date=None, 
@@ -241,8 +256,9 @@ class UserBase(UserMin):
                            reference_code=reference_code, status=status,
                            )
         
-        hashed_password = hash_password(user_id, password)
-        created_user.password = hashed_password
+        hashed_password             = hash_password(user_id, password)
+        created_user.password       = hashed_password
+        created_user.referral_code  = cls._generate_referral_code()
         
         
         created_user.is_email_verified          = is_email_verified
@@ -266,11 +282,14 @@ class UserBase(UserMin):
         
         mobile_phone    = kwargs.get('mobile_phone')
         password        = kwargs.get('password')
-        status          = kwargs.get('status')
+        #status          = kwargs.get('status')
         
         if mobile_phone:
             mobile_phone = mobile_phone.replace(" ", "")
         
+        if is_empty(user_acct.referral_code):
+            user_acct.referral_code = cls._generate_referral_code()
+        
         kwargs['mobile_phone'] = mobile_phone
         
         for key, value in kwargs.items():
