@@ -10,7 +10,7 @@ from trexlib.utils.string_util import is_not_empty
 from trexmodel.models.datastore.merchant_models import MerchantAcct, \
     MerchantUser
 import logging
-from trexmodel import program_conf
+from trexconf import program_conf
 from datetime import datetime
 from trexmodel.program_conf import VOUCHER_REWARD_TYPE,\
     VOUCHER_REWARD_MAX_QUANTITY,\
