@@ -43,6 +43,7 @@ FEATURE_CODE_TIER_REWARD_PROGRAM            = 'tier_reward'
 FEATURE_CODE_REWARDING_PROGRAM              = 'rewarding'
 FEATURE_CODE_REDEMPTION_PROGRAM             = 'redemption'
 FEATURE_CODE_LUCKY_DRAW_PROGRAM             = 'lucky_draw'
+FEATURE_CODE_REFERRAL_PROGRAM               = 'referral'
 
 PRODUCT_CODE_POINT_OF_SALES                 = 'pos'
 PRODUCT_CODE_LOYALTY                        = 'loyalty'
@@ -114,7 +115,7 @@ PACKAGE_FEATURE_PROGRAM_MAP = {
                                                 FEATURE_CODE_REWARDING_PROGRAM,
                                                 FEATURE_CODE_REDEMPTION_PROGRAM,
                                                 FEATURE_CODE_LUCKY_DRAW_PROGRAM,
-                                                
+                                                FEATURE_CODE_REFERRAL_PROGRAM,
                                                 ],
                                        
                                        }
@@ -197,12 +198,17 @@ PROGRAM_STATUS_DEFINE_TIER              = 'define_program_tier'
 PROGRAM_STATUS_DEFINE_REWARD            = 'define_reward'
 PROGRAM_STATUS_DEFINE_CONDITION         = 'define_condition'
 PROGRAM_STATUS_UPLOAD_TICKET_IMAGE      = 'upload_material'
+PROGRAM_STATUS_UPLOAD_MATERIAL          = 'upload_material'
 PROGRAM_STATUS_DEFINE_PRIZE             = 'define_prize'
 PROGRAM_STATUS_DEFINE_PRIZE_POSSIBILITY = 'define_prize_possibility'
 PROGRAM_STATUS_EXCLUSIVITY              = 'exclusivity'
 PROGRAM_STATUS_REVIEW                   = 'review'
 PROGRAM_STATUS_PUBLISH                  = 'published'
 PROGRAM_STATUS_DEFINE_ITEM              = 'define_item'
+PROGRAM_STATUS_DEFINE_PROMOTE_TEXT      = 'define_promote_text'
+
+PROGRAM_STATUS_DEFINE_REFERRER_REWARD   = 'define_program_referrer_reward'
+PROGRAM_STATUS_DEFINE_REFEREE_REWARD    = 'define_program_referee_reward'
 
 ACTION_AFTER_UNLOCK_TIER_NO_ACTION          = 'no_action'
 ACTION_AFTER_UNLOCK_TIER_CONSUME_REWARD     = 'consume_reward'
@@ -213,6 +219,7 @@ PROGRAM_REWARD_GIVEAWAY_METHOD_MANUAL   = 'manual'
 PROGRAM_REWARD_GIVEAWAY_METHOD_SYSTEM   = 'system'
 PROGRAM_REWARD_GIVEAWAY_METHOD_TIER     = 'tier'
 PROGRAM_REWARD_GIVEAWAY_METHOD_REDEEM   = 'redeem'
+PROGRAM_REWARD_GIVEAWAY_METHOD_REFERRAL = 'referral'
 
 GIVEAWAY_SYSTEM_CONDITION_NEW_MEMBERSHIP        = 'new_membership'
 GIVEAWAY_SYSTEM_CONDITION_RENEW_MEMBERSHIP      = 'renew_membership'
@@ -243,6 +250,14 @@ BASIC_REWARD_PROGRAM_STATUS                          = [PROGRAM_STATUS_PROGRAM_B
                                                                   PROGRAM_STATUS_PUBLISH
                                                                   ]
 
+REFERRAL_REWARD_PROGRAM_STATUS                          = [PROGRAM_STATUS_PROGRAM_BASE, 
+                                                                  PROGRAM_STATUS_DEFINE_REFERRER_REWARD, 
+                                                                  PROGRAM_STATUS_DEFINE_REFEREE_REWARD,
+                                                                  PROGRAM_STATUS_REVIEW,
+                                                                  PROGRAM_STATUS_PUBLISH
+                                                                  ]
+
+
 LITE_BASIC_REWARD_PROGRAM_STATUS                     = [PROGRAM_STATUS_PROGRAM_BASE, 
                                                                   PROGRAM_STATUS_REWARD_SCHEME, 
                                                                   PROGRAM_STATUS_REVIEW,
@@ -260,10 +275,19 @@ TIER_REWARD_PROGRAM_STATUS                          = [PROGRAM_STATUS_PROGRAM_BA
 LUCKY_DRAW_PROGRAM_STATUS                          = [
                                                                   PROGRAM_STATUS_PROGRAM_BASE, 
                                                                   #PROGRAM_STATUS_DEFINE_CONDITION,
-                                                                  PROGRAM_STATUS_UPLOAD_TICKET_IMAGE,  
-                                                                  PROGRAM_STATUS_DEFINE_PRIZE,  
+                                                                  PROGRAM_STATUS_DEFINE_PRIZE,
                                                                   PROGRAM_STATUS_DEFINE_PRIZE_POSSIBILITY,
                                                                   PROGRAM_STATUS_EXCLUSIVITY,
+                                                                  PROGRAM_STATUS_UPLOAD_TICKET_IMAGE,  
+                                                                  PROGRAM_STATUS_PUBLISH,
+                                                                  ]
+
+REFERRAL_PROGRAM_STATUS                            = [PROGRAM_STATUS_PROGRAM_BASE, 
+                                                                  PROGRAM_STATUS_DEFINE_REFERRER_REWARD, 
+                                                                  PROGRAM_STATUS_DEFINE_REFEREE_REWARD,
+                                                                  #PROGRAM_STATUS_DEFINE_PROMOTE_TEXT,
+                                                                  #PROGRAM_STATUS_UPLOAD_MATERIAL,
+                                                                  #PROGRAM_STATUS_REVIEW,
                                                                   PROGRAM_STATUS_PUBLISH,
                                                                   ]
 
@@ -273,7 +297,7 @@ ALL_PROGRAM_STATUS                            = (PROGRAM_STATUS_PROGRAM_BASE,
                                                  PROGRAM_STATUS_DEFINE_REWARD,
                                                  PROGRAM_STATUS_EXCLUSIVITY,
                                                  PROGRAM_STATUS_REVIEW,
-                                                 PROGRAM_STATUS_PUBLISH
+                                                 PROGRAM_STATUS_PUBLISH,
                                                  )
 
 REDEMPTION_CATALOGUE_STATUS_DEFINED_CATALOGUE       = 'define_catalogue'
@@ -368,6 +392,7 @@ REWARD_EXPIRATION_TYPE_AFTER_YEAR        = 'year'
 REWARD_EXPIRATION_TYPE_AFTER_MONTH       = 'month'
 REWARD_EXPIRATION_TYPE_AFTER_WEEK        = 'week'
 REWARD_EXPIRATION_TYPE_AFTER_DAY         = 'day'
+REWARD_EXPIRATION_TYPE_END_OF_MONTH      = 'eom'
 
 FIRST_DAY_OF_MONTH                       = 'month_start'
 ON_DOB_DATE                              = 'dob_date'
@@ -451,6 +476,9 @@ def get_lucky_draw_program_completed_status_index(completed_status):
 def get_redemption_catalogue_completed_status_index(completed_status):
     return REDEMPTION_CATALOGUE_STATUS.index(completed_status)
 
+def get_referral_program_completed_status_index(completed_status):
+    return REFERRAL_PROGRAM_STATUS.index(completed_status)
+
 def is_program_current_status_reach(checking_status, completed_status):
     completed_status_index  = get_program_completed_status_index(completed_status)
     checking_status_index   = get_program_completed_status_index(checking_status)
@@ -460,6 +488,15 @@ def is_program_current_status_reach(checking_status, completed_status):
     
     return checking_status_index<=completed_status_index+1
 
+def is_referral_program_current_status_reach(checking_status, completed_status):
+    completed_status_index  = get_referral_program_completed_status_index(completed_status)
+    checking_status_index   = get_referral_program_completed_status_index(checking_status)
+    
+    print('completed_status_index=%s'%completed_status_index)
+    print('checking_status_index=%s'%checking_status_index)
+    
+    return checking_status_index<=completed_status_index+1
+
 def is_voucher_current_status_reach(checking_status, completed_status):
     completed_status_index  = get_voucher_completed_status_index(completed_status)
     checking_status_index   = get_voucher_completed_status_index(checking_status)
@@ -494,6 +531,12 @@ def is_valid_to_update_program_status(checking_status, completed_status):
     
     return checking_status_index<=completed_status_index+1
 
+def is_valid_to_update_referral_program_status(checking_status, completed_status):
+    completed_status_index  = get_referral_program_completed_status_index(completed_status)
+    checking_status_index   = get_referral_program_completed_status_index(checking_status)
+    
+    return checking_status_index<=completed_status_index+1
+
 def is_valid_to_update_voucher_status(checking_status, completed_status):
     completed_status_index  = get_voucher_completed_status_index(completed_status)
     checking_status_index   = get_voucher_completed_status_index(checking_status)
@@ -524,6 +567,11 @@ def is_existing_program_status_final_state(completed_status):
     
     return completed_status_index==len(BASIC_REWARD_PROGRAM_STATUS)-1
 
+def is_existing_referral_program_status_final_state(completed_status):
+    completed_status_index  = get_referral_program_completed_status_index(completed_status)
+    
+    return completed_status_index==len(BASIC_REWARD_PROGRAM_STATUS)-1
+
 def is_existing_tier_reward_program_status_final_state(completed_status):
     completed_status_index  = get_tier_reward_program_completed_status_index(completed_status)
     
@@ -559,3 +607,8 @@ def redemption_catalogue_completed_progress_percentage(completed_status, loyalty
         return int((completed_status_index+1)/len(LITE_REDEMPTION_CATALOGUE_STATUS) * 100)
     else:
         return int((completed_status_index+1)/len(REDEMPTION_CATALOGUE_STATUS) * 100)
+
+def referral_program_completed_progress_percentage(completed_status):
+    completed_status_index  = get_referral_program_completed_status_index(completed_status)
+    print('referral_program_completed_progress_percentage: completed_status_index(%s)=%s'% (completed_status,completed_status_index))
+    return int((completed_status_index+1)/len(REFERRAL_PROGRAM_STATUS) * 100)
\ No newline at end of file
